@@ -10,5 +10,5 @@ function()
     if (len > 1) 
         read.table(buffer)
     else
-        cat(rlb, "\n")
+        message(rlb)
 }
